@@ -85,7 +85,7 @@ extends = %(software_config_path)s
 [%(repository_name)s]
 repository = %(repository_path)s
 """ %     {'software_config_path': os.path.join(repository_path,
-                                          config['profile_url']),
+                                          config['profile_path']),
     'repository_name': repository_name,
     'repository_path' : repository_path}
   if branch is not None:
